@@ -17,7 +17,7 @@ from autocorrect.utils import words_from_archive, zero_default_dict
 
 def parse(lang_sample):
     """tally word popularity using novel extracts, etc"""
-    words = words_from_archive(lang_sample)
+    words = words_from_archive(lang_sample, include_dups=True)
     counts = zero_default_dict()
     for word in words:
         counts[word] += 1
