@@ -20,16 +20,19 @@ PATH = os.path.abspath(os.path.dirname(__file__))
 BZ2 = 'words.bz2'
 RE = '[A-Za-z]+'
 
-def words_from_archive(filename, map_case=False):
+def words_from_archive(filename, include_dups=False, map_case=False):
     """extract words from a text file in the archive"""
     bz2 = os.path.join(PATH, BZ2)
     tar_path = os.path.join('words', filename)
     with closing(tarfile.open(bz2, 'r:bz2')) as t:
         with closing(t.extractfile(tar_path)) as f:
-            words = set(re.findall(RE, f.read().decode(encoding='utf-8')))
-    if map_case:
+            words = re.findall(RE, f.read().decode(encoding='utf-8'))
+    if include_dups:
+        return words
+    elif map_case:
         return {w.lower():w for w in words}
-    return words
+    else:
+        return set(words)
 
 def concat(*args):
     """reversed('th'), 'e' => 'hte'"""
